==> mysql-admin_1.0.18.orig.tar.gz: mysql-administrator-1.0.18/mysql-administrator/source/mac/MABackup.h <==
/* MABackup */

#import <Cocoa/Cocoa.h>
#import "MAPanel.h"

#include "myx_admin_public_interface.h"

@class MABackupDataSource;

@interface MABackup : MAPanel
{
    IBOutlet NSPopUpButton *connectionPopUp;
    IBOutlet NSButton *contentAddButton;
    IBOutlet NSOutlineView *contentOutline;
    IBOutlet NSButton *contentRemoveButton;
    IBOutlet NSTextField *dailyTimeText;
    IBOutlet NSButton *fullBackupButton;
    IBOutlet NSTextField *monthlyDaysText;
    IBOutlet NSTextField *monthlyTimeText;
    IBOutlet NSTextField *nameText;
    IBOutlet NSTextField *prefixText;
    IBOutlet id profileList;
    IBOutlet NSTableView *profileTable;
    IBOutlet NSButton *scheduleButton;
    IBOutlet NSPopUpButton *schedulePopUp;
    IBOutlet NSTabView *scheduleTab;
    IBOutlet NSOutlineView *schemaOutline;
    IBOutlet NSSearchField *schemaSearch;
    IBOutlet NSButton *startButton;
    IBOutlet NSTextField *statusText;
    IBOutlet NSTextField *targetText;
    IBOutlet NSPopUpButton *typePopUp;
    IBOutlet NSButton *unscheduleButton;
    IBOutlet NSTextField *weeklyTimeText;
    
    IBOutlet NSMatrix *modeMatrix;
    IBOutlet NSMatrix *optionMatrix;
    
    IBOutlet NSPanel *progressPanel;
    IBOutlet NSProgressIndicator *backupProgress;
    IBOutlet NSTextField *progressText;
    IBOutlet NSTextField *tableProgressText;
    
    NSImage *_tableIcon;
    NSImage *_schemaIcon;

    BOOL _backupAborted;
    MYX_BACKUP_PROFILE *_profile;

    MABackupDataSource *_selectionDS;
    NSMutableArray *_profiles;
}
- (IBAction)addContent:(id)sender;
- (IBAction)addProfile:(id)sender;
- (IBAction)chooseTargetDirectory:(id)sender;
- (IBAction)importProfile:(id)sender;
- (IBAction)removeContent:(id)sender;
- (IBAction)removeProfile:(id)sender;
- (IBAction)scheduleBackup:(id)sender;
- (IBAction)selectSchema:(id)sender;
- (IBAction)startBackup:(id)sender;
- (IBAction)unscheduleBackup:(id)sender;
- (IBAction)abortBackup:(id)sender;
@end

==> mysql-admin_1.0.20.orig.tar.gz: mysql-administrator-1.0.20/mysql-administrator/source/mac/MABackup.h <==
/* MABackup */

#import <Cocoa/Cocoa.h>
#import "MAPanel.h"
#import <MySQLToolsCommon/MTableView.h>

#include "myx_admin_public_interface.h"

@class MABackupDataSource;

@interface MABackup : MAPanel
{
    IBOutlet NSPopUpButton *connectionPopUp;
    IBOutlet NSButton *contentAddButton;
    IBOutlet NSOutlineView *contentOutline;
    IBOutlet NSButton *contentRemoveButton;
    IBOutlet NSTextField *dailyTimeText;
    IBOutlet NSButton *fullBackupButton;
    IBOutlet NSTextField *monthlyDaysText;
    IBOutlet NSTextField *monthlyTimeText;
    IBOutlet NSTextField *nameText;
    IBOutlet NSTextField *prefixText;
//    IBOutlet id profileList;
    IBOutlet MTableView *profileTable;
    IBOutlet NSButton *scheduleButton;
    IBOutlet NSPopUpButton *schedulePopUp;
    IBOutlet NSTabView *scheduleTab;
    IBOutlet NSOutlineView *schemaOutline;
    IBOutlet NSSearchField *schemaSearch;
    IBOutlet NSButton *startButton;
    IBOutlet NSTextField *statusText;
    IBOutlet NSTextField *targetText;
    IBOutlet NSPopUpButton *typePopUp;
    IBOutlet NSButton *unscheduleButton;
    IBOutlet NSTextField *weeklyTimeText;
    
    IBOutlet NSMatrix *modeMatrix;
    IBOutlet NSMatrix *optionMatrix;
    
    IBOutlet NSPanel *progressPanel;
    IBOutlet NSProgressIndicator *backupProgress;
    IBOutlet NSTextField *progressText;
    IBOutlet NSTextField *tableProgressText;
    
    IBOutlet NSTabView *tabView;
    
    NSImage *_tableIcon;
    NSImage *_schemaIcon;

    BOOL _backupAborted;
    MYX_BACKUP_PROFILE *_profile;

    MABackupDataSource *_selectionDS;
    NSMutableArray *_profiles;
}
- (IBAction)addContent:(id)sender;
- (IBAction)addProfile:(id)sender;
- (IBAction)chooseTargetDirectory:(id)sender;
- (IBAction)importProfile:(id)sender;
- (IBAction)removeContent:(id)sender;
- (IBAction)removeProfile:(id)sender;
- (IBAction)scheduleBackup:(id)sender;
- (IBAction)startBackup:(id)sender;
- (IBAction)unscheduleBackup:(id)sender;
- (IBAction)abortBackup:(id)sender;
@end
